@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "progressstatusbarwidgettest.h"
-#include "../progressstatusbarwidget.h"
-#include <QTest>
 #include "../progressdialog.h"
+#include "../progressstatusbarwidget.h"
 #include "../statusbarprogresswidget.h"
+#include <QTest>
 QTEST_MAIN(ProgressStatusBarWidgetTest)
 
 ProgressStatusBarWidgetTest::ProgressStatusBarWidgetTest(QObject *parent)
@@ -18,7 +18,7 @@ ProgressStatusBarWidgetTest::ProgressStatusBarWidgetTest(QObject *parent)
 
 void ProgressStatusBarWidgetTest::shouldHaveDefaultValue()
 {
-    QWidget *widget = new QWidget;
+    auto widget = new QWidget;
     KPIM::ProgressStatusBarWidget w(widget, widget);
     widget->show();
 
