@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class ProgressStatusBarWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit ProgressStatusBarWidgetTest(QObject *parent = nullptr);
-    ~ProgressStatusBarWidgetTest() = default;
+    ~ProgressStatusBarWidgetTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
