@@ -1,19 +1,19 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "statusbarprogresswidgettest.h"
-#include "../statusbarprogresswidget.h"
 #include "../progressdialog.h"
 #include "../progressmanager.h"
-#include <QTest>
+#include "../statusbarprogresswidget.h"
 #include <QHBoxLayout>
+#include <QProgressBar>
 #include <QPushButton>
 #include <QStackedWidget>
-#include <QProgressBar>
 #include <QStandardPaths>
+#include <QTest>
 #include <progresswidget/ssllabel.h>
 QTEST_MAIN(StatusbarProgressWidgetTest)
 
@@ -25,8 +25,8 @@ StatusbarProgressWidgetTest::StatusbarProgressWidgetTest(QObject *parent)
 
 void StatusbarProgressWidgetTest::shouldHaveDefaultValue()
 {
-    QWidget *widget = new QWidget;
-    auto *progress = new KPIM::ProgressDialog(widget, widget);
+    auto widget = new QWidget;
+    auto progress = new KPIM::ProgressDialog(widget, widget);
     KPIM::StatusbarProgressWidget w(progress, widget);
     auto *boxLayout = w.findChild<QHBoxLayout *>(QStringLiteral("boxLayout"));
     QVERIFY(boxLayout);
