@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,7 +7,7 @@
 
 #include "kdepim_export.h"
 #include <QObject>
-
+#include <memory>
 namespace KPIM
 {
 class StatusbarProgressWidget;
@@ -21,12 +21,12 @@ class KDEPIM_EXPORT ProgressStatusBarWidget : public QObject
     Q_OBJECT
 public:
     explicit ProgressStatusBarWidget(QWidget *alignWidget, QWidget *parent = nullptr, unsigned int showTypeProgressItem = 0);
-    ~ProgressStatusBarWidget();
+    ~ProgressStatusBarWidget() override;
 
     Q_REQUIRED_RESULT KPIM::StatusbarProgressWidget *littleProgress() const;
 
 private:
-    ProgressStatusBarWidgetPrivate *const d;
+    std::unique_ptr<ProgressStatusBarWidgetPrivate> const d;
 };
 }
 
